@@ -26,6 +26,7 @@
 //! ## Supported databases
 //!
 //! * SQlite3 (using [diesel](diesel) under the hood).
+//! * MySQL (using [diesel](diesel) under the hood).
 //!
 //! ## Examples
 //!
@@ -36,7 +37,9 @@
 //!
 //! ```rust
 //! use naphtha::{DatabaseConnection, DatabaseConnect};
-//! let db = DatabaseConnection::connect(":memory:");
+//! // This is the only line required to be changed to switch database types.
+//! type DbBackend = diesel::SqliteConnection;
+//! let db: DatabaseConnection<DbBackend> = DatabaseConnection::connect(":memory:").unwrap();
 //! // do some database work
 //! ```
 //!
@@ -52,15 +55,21 @@
 //!     naphtha::{
 //!         model,
 //!         DatabaseModel,
+//!         DatabaseModelModifier,
 //!         DatabaseInsertHandler,
 //!         DatabaseUpdateHandler,
 //!         DatabaseRemoveHandler
 //!     },
 //!     diesel::table
 //! };
-//! #[cfg(any(feature = "barrel-full", feature = "barrel-sqlite"))]
+//! #[cfg(any(feature = "barrel-sqlite", feature = "barrel-mysql"))]
 //! use naphtha::barrel::{types, DatabaseSqlMigration, Migration};
 //!
+//! // It is recommended to wrap the actual used database type in a crate-global
+//! // alias. If the database is changed later, this is the only line that needs
+//! // to be adjusted to the new database type.
+//! pub(crate) type DbBackend = diesel::SqliteConnection;
+//!
 //! #[model(table_name = "persons")]
 //! pub struct Person {
 //!     id: i32,
@@ -132,7 +141,7 @@
 //!     // id member is set to the correct number given by the database.
 //!
 //!     // do a custom query to the database
-//!     db.custom::<diesel::result::QueryResult::<Person>, _>(|c| {
+//!     db.custom::<diesel::result::QueryResult::<Person>, _>(|c: &DbBackend| {
 //!         use schema::{persons, persons::dsl::*};
 //!         persons.filter(id.eq(1)).first(c)
 //!     });
@@ -141,11 +150,7 @@
 //!     // p not available anymore
 //! }
 //! ```
-//!
-//! ## Upcoming
-//!
-//! * The query by methods will be implemented.
-//! * More databases will be implemented, at least PostgreSQL and MySql.
+
 use std::sync::{Arc, Mutex, MutexGuard, PoisonError};
 
 /// Defines your `struct` as a model and implements the required traits for
@@ -153,7 +158,7 @@ use std::sync::{Arc, Mutex, MutexGuard, PoisonError};
 /// supported.
 pub use naphtha_proc_macro::model;
 
-#[cfg(any(feature = "barrel-full", feature = "barrel-sqlite",))]
+#[cfg(any(feature = "barrel-sqlite", feature = "barrel-mysql",))]
 /// Re-exports the [barrel] crate including small additions required by naphtha.
 pub mod barrel;
 mod database_impl;
@@ -219,7 +224,7 @@ where
 }
 
 /// Methods that are called before and after the transaction executed when
-/// the [insert] method is called.
+/// the [insert](DatabaseModelModifier::insert) method is called.
 /// Can be used to do custom changes to the database or the model instance.
 /// Useful for extending the basic CRUD model.
 #[allow(unused_variables)]
@@ -231,7 +236,7 @@ pub trait DatabaseInsertHandler<T> {
 }
 
 /// Methods that are called before and after the transaction executed when
-/// the [update] method is called.
+/// the [update](DatabaseModelModifier::update) method is called.
 /// Can be used to do custom changes to the database or the model instance.
 /// Useful for extending the basic CRUD model.
 #[allow(unused_variables)]
@@ -243,7 +248,7 @@ pub trait DatabaseUpdateHandler<T> {
 }
 
 /// Methods that are called before and after the transaction executed when
-/// the [remove] method is called.
+/// the [remove](DatabaseModelModifier::remove) method is called.
 /// Can be used to do custom changes to the database or the model instance.
 /// Useful for extending the basic CRUD model.
 #[allow(unused_variables)]
